@@ -11,7 +11,7 @@ except ImportError as e:
     from steps import step
     from utility import update_dump_report
 
-def run_simulation(n_of_families = 500,
+def run_simulation(n_of_families = 250,
     use_steps = True,
     number_of_steps = 150,
     incubation_days = 5,
@@ -20,19 +20,20 @@ def run_simulation(n_of_families = 500,
     restriction_duration = 21,
     social_distance_strictness = 2,
     restriction_decreasing = True,
-    n_initial_infected_nodes = 2,
+    n_initial_infected_nodes = 3,
     R_0 = 2.9,
-    n_test = 10,
+    n_test = 3,
     policy_test = "Random",
     contact_tracing_efficiency = 0.8,
     contact_tracing_duration = 14,
     quarantine_efficiency = 0.4,
-    use_random_seed = True,
-    seed = 0,
+    use_fixed_seed = True,
+    seed = 42,
     use_probabilities = False,
-    gamma = 0.011,
+    alpha = 0.5,
+    gamma = 0.003,
     lambdaa = 0.02,
-    dump_type = "full",
+    dump_type = None,
     path = None):
     """
     Execute the simulation and dump/return resulting networks
@@ -89,7 +90,7 @@ def run_simulation(n_of_families = 500,
     quarantine_efficiency: float
         The percentage of contacts put under quarantine
 
-    use_random_seed: bool
+    use_fixed_seed: bool
         Id use or not a fixed random seed
 
     seed: int
@@ -98,6 +99,9 @@ def run_simulation(n_of_families = 500,
     use_probabilities: bool
         Enables probabilities of being infected estimation
 
+    alpha: float
+        Parameter to regulate probability of being infected contact decay. Domain = (0, 1). Lower values corresponds to higher probability decay
+
     gamma: float
         Parameter to regulate probability of being infected contact diffusion. Domain = (0, +inf). Higher values corresponds to stronger probability diffusion
 
@@ -122,7 +126,7 @@ def run_simulation(n_of_families = 500,
     """
 
     # generate new edges
-    if use_random_seed:
+    if use_fixed_seed:
         np.random.seed(seed = seed)
         random.seed(seed)
     else:
@@ -188,6 +192,9 @@ def run_simulation(n_of_families = 500,
     if dump_type != "full" and dump_type != "light":
         print("Invalid dump type")
         sys.exit()
+    if path == None:
+        print("Invalid path")
+        sys.exit()
     if not use_probabilities and policy_test == "PBI":
         print("Cannot use PBI if probability of being infected is not enabled")
         sys.exit()
@@ -235,35 +242,37 @@ def run_simulation(n_of_families = 500,
         to_dump['positive'] = list()
         to_dump['tested'] = list()
         to_dump['total'] = list()
+        to_dump['new_positive_counter'] = list()
+        to_dump['avg_prob_inf'] = list()
         to_dump['parameters'] = config
 
     if use_steps:
         for sim_index in range (0, number_of_steps):
-            net = step(G, sim_index, incubation_days, infection_duration, transmission_rate,
+            net, new_positive_counter = step(G, sim_index, incubation_days, infection_duration, transmission_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracing_efficiency,
-                             quarantine_efficiency, use_probabilities, gamma, lambdaa)
+                             quarantine_efficiency, use_probabilities, alpha, gamma, lambdaa)
             nets.append(net.copy())
             if dump_type == "full":
                 to_dump["nets"].append(net.copy())
             if dump_type == "light":
-                to_dump = update_dump_report(to_dump, net)
+                to_dump = update_dump_report(to_dump, net, new_positive_counter, use_probabilities)
     else:
         exposed = n_initial_infected_nodes
         infected = 0
         sim_index = 0
         while((infected + exposed) != 0):
-            net = step(G, sim_index, incubation_days, infection_duration, transmission_rate,
+            net, new_positive_counter = step(G, sim_index, incubation_days, infection_duration, transmission_rate,
                              initial_day_restriction, restriction_duration, social_distance_strictness, 
                              restriction_decreasing, nets, n_test, policy_test, contact_tracing_efficiency,
-                             quarantine_efficiency, use_probabilities, gamma, lambdaa)
+                             quarantine_efficiency, use_probabilities, alpha, gamma, lambdaa)
             nets.append(net.copy())
             sim_index += 1
 
             if dump_type == "full":
                 to_dump["nets"].append(net.copy())
             if dump_type == "light":
-                to_dump = update_dump_report(to_dump, net)
+                to_dump = update_dump_report(to_dump, net, new_positive_counter, use_probabilities)
             
             network_report = Counter(net.vs["agent_status"])
             infected = network_report["I"]
@@ -302,11 +311,12 @@ def main():
         contact_tracing_efficiency = float(input("Please insert a value between 0 and 1 to set the contact tracing efficiency: "))
         contact_tracing_duration = int(input("Please insert for how many days the contact tracing is computed: "))
         quarantine_efficiency = float(input("Please insert a value between 0 and 1 to set the quarantine efficiency: "))
-        use_random_seed = int(input("Press 1 use a fixed a random seed or 0 to pick a random seed: "))
-        if use_random_seed:
+        use_fixed_seed = int(input("Press 1 use a fixed a random seed or 0 to pick a random seed: "))
+        if use_fixed_seed:
             seed = int(input("Please insert the random seed: "))
         use_probabilities = int(input("Press 1 to enable estimation of probabilities of being infected, 0 otherwise: "))
         if use_probabilities:
+            alpha = float(input("Please insert the value of alpha: "))
             gamma = float(input("Please insert the value of gamma: "))
             lambdaa = float(input("Please insert the value of lambdaa: "))
         dump_type = input("Please insert the dump type. Can be either full of light: ")
@@ -315,7 +325,7 @@ def main():
         run_simulation(n_of_families, use_steps, number_of_steps, incubation_days, infection_duration,
             initial_day_restriction, restriction_duration, social_distance_strictness, restriction_decreasing,
             n_initial_infected_nodes, R_0, n_test, policy_test, contact_tracing_efficiency, contact_tracing_duration,
-            quarantine_efficiency, use_random_seed, seed, use_probabilities, gamma, lambdaa, dump_type, path)
+            quarantine_efficiency, use_fixed_seed, seed, use_probabilities, alpha, gamma, lambdaa, dump_type, path)
     else:
         dump_type = input("Please insert the dump type. Can be either full of light: ")
         path = input("Please insert the path with the file to dump. Please omit file type, that will be set automatically: ")
