@@ -28,8 +28,6 @@ def generate_family_edges(G):
             and G.vs[edge[1]]["agent_status"] != "D" \
             and not G.vs[edge[0]]["quarantine"] \
             and not G.vs[edge[1]]["quarantine"]:
-            #and not (edge[0], edge[1]) in toAdd
-            #and not (edge[1], edge[0]) in toAdd:
                 toAdd.append(edge)
 
     weights = np.random.randint(3, 8, len(toAdd))
@@ -82,8 +80,6 @@ def generate_occfreq_edges(G, edge_category, restriction_value):
             and not G.vs[edge[0]]["quarantine"] \
             and not G.vs[edge[1]]["quarantine"] \
             and not G[edge[0], edge[1]]:
-            #and not (edge[0], edge[1]) in toAdd \
-            #and not (edge[1], edge[0]) in toAdd:
                 toAdd.append(edge)
 
     weights = np.random.randint(1, 6, len(toAdd))
@@ -126,8 +122,6 @@ def generate_random_edges(G, number_of_random_edges, restriction_value):
         and not G.vs[source]["quarantine"] \
         and not G.vs[target]["quarantine"] \
         and not G[source, target]:
-        #and not (source, target) in toAdd \
-        #and not (target, source) in toAdd:
             toAdd.append((source, target))
 
     G.add_edges(toAdd)
@@ -173,7 +167,7 @@ def step_edges(G, restriction_value):
             toRemove.append(edge)
     G.delete_edges(toRemove)  
 
-def step_spread(G, incubation_days, infection_duration, transmission_rate, use_probabilities, gamma):
+def step_spread(G, incubation_days, infection_duration, transmission_rate, use_probabilities, alpha, gamma):
     """
     Make the infection spread across the network
     
@@ -194,6 +188,9 @@ def step_spread(G, incubation_days, infection_duration, transmission_rate, use_p
     use_probabilities: bool
         Enables probabilities of being infected estimation
 
+    alpha: float
+        Parameter to regulate probability of being infected contact decay. Domain = (0, 1). Lower values corresponds to higher probability decay
+
     gamma: float
         Parameter to regulate probability of being infected contact diffusion. Domain = (0, +inf). Higher values corresponds to stronger probability diffusion
 
@@ -270,13 +267,13 @@ def step_spread(G, incubation_days, infection_duration, transmission_rate, use_p
             weight = edge["weight"]
             source = edge.source
             target = edge.target
-            nodes_contact_probs[source] *= 1 - old_prob[target] * (1 - np.e**(-gamma * weight))
-            nodes_contact_probs[target] *= 1 - old_prob[source] * (1 - np.e**(-gamma * weight))
+            nodes_contact_probs[source] *= 1 - (1 - 1 / (1 + alpha * 21)) * old_prob[target] * (1 - np.e**(- gamma * weight))
+            nodes_contact_probs[target] *= 1 - (1 - 1 / (1 + alpha * 21)) * old_prob[source] * (1 - np.e**(- gamma * weight))
 
         for node in G.vs:
             if node["agent_status"] != "D" and not (node["test_result"] == 0 and node["agent_status"] == "R"):
                 index = node.index
-                node["prob_inf"] = 1 - (1 - old_prob[index] * np.tanh(old_prob[index] + 0.5)) * nodes_contact_probs[index]
+                node["prob_inf"] = 1 - (1 / (1 + alpha * 21)) * old_prob[index] - (1 - old_prob[index]) * nodes_contact_probs[index]
    
 def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing_efficiency, quarantine_efficiency, use_probabilities, lambdaa):
     """
@@ -314,7 +311,8 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
 
     Return
     ------
-    None
+    new_positive_counter: int
+        Number of new positive nodes found on this iteration
 
     """
 
@@ -337,7 +335,7 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
          and not (node["test_result"] == 0 and node["agent_status"] == "R"):
             low_priority_test_pool.add(node.index)
 
-    low_priority_test_pool = low_priority_test_pool - high_priority_test_pool
+    low_priority_test_pool -= high_priority_test_pool
     found_positive = set()
     #cannot directly put nodes in a set cause node object are not supported
     high_priority_test_pool = [G.vs[i] for i in high_priority_test_pool]
@@ -349,6 +347,8 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
 
     to_test = list()
 
+    new_positive_counter = 0
+
     if n_new_test:
         if policy_test == "Random":
             to_test = random.sample(low_priority_test_pool, min(len(low_priority_test_pool), n_new_test))
@@ -373,15 +373,17 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
         result = perform_test(node, incubation_days, use_probabilities)
         if result:
             found_positive.add(node.index)
+            new_positive_counter += 1
             
     # tracked will contain family contacts (quarantine 100%), 
     # possibly_tracked will contain other contacts, quarantine influenced by contact tracing efficiency
+    ct_nets = list(nets) + [G.copy()]
 
-    if len(found_positive) > 0 and len(nets) > 0:
+    if len(found_positive) > 0:
         tracked = set()
         possibly_tracked = set()
         # trace contacts
-        for net in nets:
+        for net in ct_nets:
             for edge in net.es:
                 if edge["category"] == "family_contacts" \
                 and (edge.source in found_positive or edge.target in found_positive):
@@ -396,8 +398,8 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
                         possibly_tracked.add(G.vs[edge.source].index)
         
         # set diff to remove double contacts
-        possibly_tracked = possibly_tracked - tracked
-        if len(possibly_tracked) > int(len(possibly_tracked) * contact_tracing_efficiency):
+        possibly_tracked -= tracked
+        if int(len(possibly_tracked) * contact_tracing_efficiency) > 0:
             possibly_tracked = random.sample(possibly_tracked, int(len(possibly_tracked) * contact_tracing_efficiency))
         else:
             possibly_tracked = list(possibly_tracked)
@@ -414,16 +416,16 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
 
             
             # update prob of being infected of past tracked contact 
-                for net_index in range(len(nets)):
-                    net = nets[-net_index]
+                for net_index in range(1, len(nets) + 1):
+                    net = nets[- net_index]
                     for contact in net.neighborhood(node)[1:]:
                         contact_node = G.vs[contact]
                         if contact_node["agent_status"] != "D" and not (contact_node["test_result"] == 0 and contact_node["agent_status"] == "R"):
                             if contact in tracked + possibly_tracked:
                                 current_contact_weight = net[node, contact]
+                                # use net_index instead of net_index + 1 since net index is already +1 from line above 
                                 contact_node["prob_inf"] = contact_node["prob_inf"] \
-                                                            + lambdaa * np.e**(- (net_index + 1) * (1 / current_contact_weight)) * (1 - contact_node["prob_inf"])
-
+                                                            + lambdaa * np.e**(- (net_index) * (1 / current_contact_weight)) * (1 - contact_node["prob_inf"])
         
         possibly_quarantine = list()
 
@@ -447,14 +449,15 @@ def step_test(G, nets, incubation_days, n_new_test, policy_test, contact_tracing
         to_quarantine = [G.vs[i] for i in tracked + possibly_quarantine]
         
         # put them in quarantine
-        if to_quarantine != list() and to_quarantine != None:
-            for node in to_quarantine:
-                node["quarantine"] = 14
+        for node in to_quarantine:
+            node["quarantine"] = 14
+
+    return new_positive_counter
 
 def step(G, step_index, incubation_days, infection_duration, transmission_rate,
          initial_day_restriction, restriction_duration, social_distance_strictness,
          restriction_decreasing, nets, n_test, policy_test, contact_tracing_efficiency,
-         quarantine_efficiency, use_probabilities, gamma, lambdaa):
+         quarantine_efficiency, use_probabilities, alpha, gamma, lambdaa):
     """
     Advance the simulation of one step
     
@@ -507,6 +510,9 @@ def step(G, step_index, incubation_days, infection_duration, transmission_rate,
     use_probabilities: bool
         Enables probabilities of being infected estimation
 
+    alpha: float
+        Parameter to regulate probability of being infected contact decay. Domain = (0, 1). Lower values corresponds to higher probability decay
+
     gamma: float
         Parameter to regulate probability of being infected contact diffusion. Domain = (0, +inf). Higher values corresponds to stronger probability diffusion
 
@@ -517,6 +523,10 @@ def step(G, step_index, incubation_days, infection_duration, transmission_rate,
     ------
     G: ig.Graph()
         The contact network
+
+    new_positive_counter: int
+        Number of new positive nodes found on this iteration
+
         
     """
 
@@ -537,13 +547,9 @@ def step(G, step_index, incubation_days, infection_duration, transmission_rate,
             step_edges(G, 1)
     
     # spread infection
-    step_spread(G, incubation_days, infection_duration, transmission_rate, use_probabilities, gamma)
+    step_spread(G, incubation_days, infection_duration, transmission_rate, use_probabilities, alpha, gamma)
           
     # make some test on nodes
-    step_test(G, nets, incubation_days, n_test, policy_test, contact_tracing_efficiency, quarantine_efficiency, use_probabilities, lambdaa)
+    new_positive_counter = step_test(G, nets, incubation_days, n_test, policy_test, contact_tracing_efficiency, quarantine_efficiency, use_probabilities, lambdaa)
 
-    agent_status_report = list()
-    for node in G.vs:
-        agent_status_report.append(node["agent_status"])
-
-    return G  
\ No newline at end of file
+    return G, new_positive_counter
\ No newline at end of file
