@@ -57,7 +57,7 @@ def reset_network(G):
         if "prob_inf" in G.vs.attributes():
             node["prob_inf"] = 0.0
 
-def update_dump_report(to_dump, net):
+def update_dump_report(to_dump, net, new_positive_counter, use_probabilities):
     """
     Update the simulation dump in case light dump is selected
     
@@ -69,6 +69,12 @@ def update_dump_report(to_dump, net):
     net: ig.Graph()
         The contact network
 
+    new_positive_counter: int
+        Number of new positive nodes found on this iteration
+
+    use_probabilities: bool
+        Enables probabilities of being infected estimation
+
     Return
     ------
     to_dump: dict
@@ -96,6 +102,9 @@ def update_dump_report(to_dump, net):
     to_dump['quarantined'].append(quarantined)
     to_dump['positive'].append(positive)
     to_dump['tested'].append(tested)
+    to_dump['new_positive_counter'].append(new_positive_counter)
+    if use_probabilities:
+        to_dump['avg_prob_inf'].append(np.mean(net.vs['prob_inf']))
     to_dump['total'].append(sum(network_report.values()))
 
     return to_dump
@@ -144,7 +153,6 @@ def compute_sd_reduction(step_index, initial_day_restriction, restriction_durati
     for i in range(1, len(strictness_sequence)):
       strictness_sequence[i] += strictness_sequence[i - 1]
 
-
     social_distance_reduction = None
 
     for i in range(len(strictness_sequence)):
